==> koshoten.net-2.1.3.tar.gz: koshoten-net/catalog/includes/column_left.php <==
<?php
/*
  $Id: column_left.php,v 1.2 2005/08/01 08:08:15 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

  if (KN_CFG_USE_COLUMN_LEFT == 'true') {
    echo '    <td id="leftColumn"><div class="sideContents">' . "\n";
    // BOX
    if (KN_CFG_BOX_SEARCH == 2) {
      require(DIR_WS_BOXES . 'search.php');
    }
    // Ϣ۸BOX
    if (KN_CFG_BOX_GETA_SEARCH == 2) {
      require(DIR_WS_BOXES . 'geta_search.php');
    }
    // ƥ꡼BOX
    if (KN_CFG_BOX_CATEGORIES == 2) {
      if ( (USE_CACHE == 'true') && !SID ) {
        echo tep_cache_categories_box();
      } else {
        include(DIR_WS_BOXES . 'categories.php');
      }
    }
    // ɲʬΰBOX
    if (KN_CFG_BOX_MANUFACTURERS == 2) {
      include(DIR_WS_BOXES . 'manufacturers.php');
    }
    // åԥ󥰥BOX
    if (KN_CFG_BOX_SHOPPING_CART == 2) {
      require(DIR_WS_BOXES . 'shopping_cart.php');
    }
    // GETAơBOX
    if (KN_CFG_BOX_GETA_THEMES == 2) {
      require(DIR_WS_BOXES . 'geta_themes.php');
    }
    // 徦BOX
    if (KN_CFG_BOX_WHATS_NEW == 2) {
      require(DIR_WS_BOXES . 'whats_new.php');
    }
    // ʸBOX
    if (KN_CFG_BOX_ORDER_HISTORY == 2) {
      if (tep_session_is_registered('customer_id')) include(DIR_WS_BOXES . 'order_history.php');
    }
    // ե᡼BOX
    if (KN_CFG_BOX_INFORMATION == 2) {
      require(DIR_WS_BOXES . 'information.php');
    }
    // ٥ȥ顼BOX
    if (KN_CFG_BOX_BEST_SELLERS == 2) {
      require(DIR_WS_BOXES . 'best_sellers.php');
    }
    if (isset($HTTP_GET_VARS['products_id'])) {
      // ͧΤ餻BOX
      if (KN_CFG_BOX_TELL_A_FRIEND == 2) {
        if (basename($PHP_SELF) != FILENAME_TELL_A_FRIEND) include(DIR_WS_BOXES . 'tell_a_friend.php');
      }
    } else {
      // òBOX
      if (KN_CFG_BOX_SPECIALS == 2) {
        include(DIR_WS_BOXES . 'specials.php');
      }
    }
    // ɾBOX
    if ((KN_CFG_BOX_REVIEWS == 2) && (KN_CFG_USE_REVIEWS == 'true')) {
      require(DIR_WS_BOXES . 'reviews.php');
    }

    if (substr(basename($PHP_SELF), 0, 8) != 'checkout') {
      // BOX
      if (KN_CFG_BOX_LANGUAGES == 2) {
        include(DIR_WS_BOXES . 'languages.php');
      }
      // ̲BOX
      if (KN_CFG_BOX_CURRENCIES == 2) {
        include(DIR_WS_BOXES . 'currencies.php');
      }
    }
    // Τ餻ʸ
    $si_column_left_query = tep_db_query("select shop_info_title, shop_info_value, allow_tags from " . TABLE_SHOP_INFO . " where shop_info_key = 'SHOP_INFO_COLUMN_LEFT'");
    $si_column_left = tep_db_fetch_array($si_column_left_query);
    if (isset($si_column_left['shop_info_value']) && tep_not_null($si_column_left['shop_info_value'])) {
      echo '      <div id="siColumnLeft">';
      if ($si_column_left['allow_tags']) {
        echo $si_column_left['shop_info_value'];
      } else {
        echo nl2br(htmlspecialchars($si_column_left['shop_info_value']));
      }
      echo '</div>' . "\n";
    }
    echo '    </div></td>' . "\n";
  }
?>

==> koshoten.net-2.1.6.tar.gz: koshoten-net/catalog/includes/column_left.php <==
<?php
/*
  $Id: column_left.php,v 1.3 2006/03/23 02:12:25 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

  if (KN_CFG_USE_COLUMN_LEFT == 'true') {
    echo '    <td id="leftColumn"><div class="sideContents">' . "\n";
    // BOX
    if (KN_CFG_BOX_SEARCH == 2) {
      require(DIR_WS_BOXES . 'search.php');
    }
    // Ϣ۸BOX
    if (KN_CFG_BOX_GETA_SEARCH == 2) {
      require(DIR_WS_BOXES . 'geta_search.php');
    }
    // ƥ꡼BOX
    if (KN_CFG_BOX_CATEGORIES == 2) {
      if ( (USE_CACHE == 'true') && !SID ) {
        echo tep_cache_categories_box();
      } else {
        include(DIR_WS_BOXES . 'categories.php');
      }
    }
    // ɲʬΰBOX
    if (KN_CFG_BOX_MANUFACTURERS == 2) {
      include(DIR_WS_BOXES . 'manufacturers.php');
    }
    // åԥ󥰥BOX
    if (KN_CFG_BOX_SHOPPING_CART == 2) {
      if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
      } else {
        require(DIR_WS_BOXES . 'shopping_cart.php');
      }
    }
    // GETAơBOX
    if (KN_CFG_BOX_GETA_THEMES == 2) {
      require(DIR_WS_BOXES . 'geta_themes.php');
    }
    // 徦BOX
    if (KN_CFG_BOX_WHATS_NEW == 2) {
      require(DIR_WS_BOXES . 'whats_new.php');
    }
    // ʸBOX
    if (KN_CFG_BOX_ORDER_HISTORY == 2) {
      if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
      } else {
        if (tep_session_is_registered('customer_id')) include(DIR_WS_BOXES . 'order_history.php');
      }
    }
    // ե᡼BOX
    if (KN_CFG_BOX_INFORMATION == 2) {
      require(DIR_WS_BOXES . 'information.php');
    }
    // ٥ȥ顼BOX
    if (KN_CFG_BOX_BEST_SELLERS == 2) {
      if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
      } else {
        require(DIR_WS_BOXES . 'best_sellers.php');
      }
    }
    if (isset($HTTP_GET_VARS['products_id'])) {
      // ͧΤ餻BOX
      if (KN_CFG_BOX_TELL_A_FRIEND == 2) {
        if (basename($PHP_SELF) != FILENAME_TELL_A_FRIEND) include(DIR_WS_BOXES . 'tell_a_friend.php');
      }
    } else {
      // òBOX
      if (KN_CFG_BOX_SPECIALS == 2) {
        include(DIR_WS_BOXES . 'specials.php');
      }
    }
    // ɾBOX
    if ((KN_CFG_BOX_REVIEWS == 2) && (KN_CFG_USE_REVIEWS == 'true')) {
      require(DIR_WS_BOXES . 'reviews.php');
    }

    if (substr(basename($PHP_SELF), 0, 8) != 'checkout') {
      // BOX
      if (KN_CFG_BOX_LANGUAGES == 2) {
        include(DIR_WS_BOXES . 'languages.php');
      }
      // ̲BOX
      if (KN_CFG_BOX_CURRENCIES == 2) {
        include(DIR_WS_BOXES . 'currencies.php');
      }
    }
    // Τ餻ʸ
    $si_column_left_query = tep_db_query("select shop_info_title, shop_info_value, allow_tags from " . TABLE_SHOP_INFO . " where shop_info_key = 'SHOP_INFO_COLUMN_LEFT'");
    $si_column_left = tep_db_fetch_array($si_column_left_query);
    if (isset($si_column_left['shop_info_value']) && tep_not_null($si_column_left['shop_info_value'])) {
      echo '      <div id="siColumnLeft">';
      if ($si_column_left['allow_tags']) {
        echo $si_column_left['shop_info_value'];
      } else {
        echo nl2br(htmlspecialchars($si_column_left['shop_info_value']));
      }
      echo '</div>' . "\n";
    }
    echo '    </div></td>' . "\n";
  }
?>
